@@ -22,23 +22,34 @@ sub run{
     local $SIG{__WARN__} = sub
       {
           foreach( @_ ){
-              if( m/^fatal:/ ){
-                  die( "$_\n" );
-              }elsif( m/^git:/ ){
-                  warn( "$_\n" );
-              }else{
-                  # Other git output
-                  print "Git warning: $_\n";
-              }
+              # Stupidly, not all Git output goes to output... some goes to warnings...
+              print "Git WARN: $_\n";
+          }
+          # Allow a repeat
+          if( pause() ){
+              return $self->run( $character, $event );
           }
       };
 
     my $git = $character->git();
     my @cmd = $event->action();
     push( @cmd, @{ $event->args() } );
-    $self->{logger}->debug( sprintf( "%10s : %s# git %s", $character->name(), $character->dir(), join( ' ', @cmd ) ) );
-    return $git->run( @cmd ) . "\n";
+    $self->{logger}->info( sprintf( "Git (%s): git %s", $character->name(), join( ' ', @cmd ) ) );
+    my $rtn = $git->run( @cmd );
+    if( $rtn !~ m/^\s*$/ ){
+        $rtn .= "\n";
+    }
+    return $rtn;
 }
 
+sub pause{
+    print "Repeat (r) or Continue ([enter])?";
+    my $in = <STDIN>;
+    chomp( $in );
+    if( lc( $in ) eq 'r' ){
+        return 1;
+    }
+    return undef;
+}
 
 1;
